==> dvlp-9.1.1.tgz: package/bundle-worker.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var worker_threads = _interopDefault(require('worker_threads'));
var pluginCommonjs = _interopDefault(require('@rollup/plugin-commonjs'));
var pluginJson = _interopDefault(require('@rollup/plugin-json'));
var pluginReplace = _interopDefault(require('@rollup/plugin-replace'));
var pluginNodeResolve = _interopDefault(require('@rollup/plugin-node-resolve'));
var pirates = _interopDefault(require('pirates'));
var fs = _interopDefault(require('fs'));
var isModule = _interopDefault(require('is-module'));
var module$1 = _interopDefault(require('module'));
var path = _interopDefault(require('path'));
var sucrase = _interopDefault(require('sucrase'));
var rollup$1 = _interopDefault(require('rollup'));

let resolvePlugin = pluginNodeResolve;

if ('default' in resolvePlugin) {
  // @ts-ignore
  resolvePlugin = resolvePlugin.default;
}

const plugins = [
  // @ts-ignore
  pluginReplace({
    'process.env.NODE_ENV': `"${process.env.NODE_ENV}"` || '"development"',
  }),
  // @ts-ignore
  resolvePlugin({
    mainFields: ['browser', 'module', 'main'],
  }),
  // @ts-ignore
  pluginJson(),
  // @ts-ignore
  pluginCommonjs({
    namedExports: {
      react: [
        'Children',
        'Component',
        'Fragment',
        'Profiler',
        'PureComponent',
        'StrictMode',
        'Suspense',
        '__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED',
        'cloneElement',
        'createContext',
        'createElement',
        'createFactory',
        'createRef',
        'forwardRef',
        'isValidElement',
        'lazy',
        'memo',
        'useCallback',
        'useContext',
        'useDebugValue',
        'useEffect',
        'useImperativeHandle',
        'useLayoutEffect',
        'useMemo',
        'useReducer',
        'useRef',
        'useState',
        'version',
      ],
      'react-dom': [
        '__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED',
        'createPortal',
        'findDOMNode',
        'flushSync',
        'hydrate',
        'render',
        'unmountComponentAtNode',
        'unstable_batchedUpdates',
        'unstable_createPortal',
        'unstable_renderSubtreeIntoContainer',
        'version',
      ],
      'react-is': ['isContextConsumer', 'isValidElementType'],
    },
    sourceMap: false,
  }),
];

/**
 * Retrieve the default Rollup-config
 * @returns { import("rollup").RollupOptions }
 */
var getDefaultRollupConfig = function getDefaultRollupConfig() {
  return {
    // Only bundle local package files
    external: (id, parent, isResolved) => {
      // Skip if already handled by plugin
      if (isResolved || (parent && parent.includes('?commonjs-proxy'))) {
        return false;
      }
      return /^[^./\0]/.test(id);
    },
    plugins: plugins.slice(),
    treeshake: false,
    output: {
      format: 'es',
      sourcemap: false,
    },
  };
};

var defaultRollupConfig = {
	getDefaultRollupConfig: getDefaultRollupConfig
};

function createCommonjsModule(fn, basedir, module) {
	return module = {
	  path: basedir,
	  exports: {},
	  require: function (path, base) {
      return commonjsRequire(path, (base === undefined || base === null) ? module.path : base);
    }
	}, fn(module, module.exports), module.exports;
}

function commonjsRequire () {
	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
}

var module_1 = createCommonjsModule(function (module) {

const { addHook } = pirates;

// @ts-ignore

// Work around @rollup/plugin-commonjs dynamic require
// @ts-ignore
const loadModule = module$1._load;



const IMPORT_EXTS = ['.js', '.mjs'];
const IMPORT_EXTS_TRANSPILER = ['.js', '.jsx', '.mjs', '.ts', '.tsx'];
// Sync with config.js#extensionsByType
const JS_EXTENSIONS = ['.ts', '.tsx', '.mjs', '.jsx', '.js', '.json'];
const RE_TRANSPILER_HANDLES_SERVER = /\(\s?[a-zA-Z]+,\s?[a-zA-Z]+\s?\)/;

/** @type { () => void } */
let revertHook;

module.exports = {
  isModule: isModule$1,
  importModule,
};

/**
 * Determine if filePath or code is es module
 *
 * @param { string } filePathOrCode
 * @returns { boolean }
 */
function isModule$1(filePathOrCode) {
  if (
    !filePathOrCode.includes('\n') &&
    JS_EXTENSIONS.includes(path.extname(filePathOrCode))
  ) {
    filePathOrCode = fs.readFileSync(filePathOrCode, 'utf8');
  }
  return isModule(filePathOrCode);
}

/**
 * Import esm/cjs module, transpiling if necessary (via require hook)
 *
 * @param { string } modulePath
 * @param { Transpiler } [transpiler]
 * @returns { any }
 */
function importModule(modulePath, transpiler) {
  if (revertHook !== undefined) {
    revertHook();
  }

  revertHook = addHook(
    (code, filePath) => {
      // Determine if transpiler supports transpiling server modules by checking number of arguments (filePath, isServer) handled
      if (
        transpiler !== undefined &&
        RE_TRANSPILER_HANDLES_SERVER.test(transpiler.toString())
      ) {
        const transpiled = transpiler(filePath, true);

        if (transpiled !== undefined) {
          // Ignore async
          if (!(transpiled instanceof Promise)) {
            code = transpiled;
          }
        }
      }

      if (!isModule$1(code)) {
        return code;
      }

      return sucrase.transform(code, {
        transforms: ['imports'],
        filePath,
      }).code;
    },
    {
      exts: transpiler ? IMPORT_EXTS_TRANSPILER : IMPORT_EXTS,
      ignoreNodeModules: false,
    },
  );
  let mod = loadModule(modulePath, module, false);

  // Return default if only exported key
  if ('default' in mod && Object.keys(mod).length === 1) {
    mod = mod.default;
  }

  return mod;
}
});
var module_2 = module_1.isModule;
var module_3 = module_1.importModule;

/** @typedef { import("rollup").RollupOptions } RollupOptions */

const {
  isMainThread,
  parentPort,
  Worker,
  workerData,
} = worker_threads;
const {
  getDefaultRollupConfig: getDefaultRollupConfig$1,
} = defaultRollupConfig;
const { importModule } = module_1;
const { rollup } = rollup$1;

class BundleWorker {
  /**
   * Constructor
   *
   * @param { boolean } threaded
   * @param { string } [rollupConfigPath]
   */
  constructor(threaded, rollupConfigPath) {
    const defaultConfig = getDefaultRollupConfig$1();

    this.rollupConfig = rollupConfigPath
      ? mergeRollupConfig(defaultConfig, importModule(rollupConfigPath))
      : defaultConfig;
    this.worker;

    if (threaded && isMainThread) {
      // Load this file in Worker thread, passing `rollupConfigPath` as data
      this.worker = new Worker(__filename, { workerData: rollupConfigPath });
    }
  }

  /**
   * Bundle file at "inputPath"
   *
   * @param { string } inputPath
   * @param { string } outputPath
   * @param { string } sourcePrefix
   */
  async bundle(inputPath, outputPath, sourcePrefix) {
    if (this.worker) {
      return new Promise((resolve, reject) => {
        this.worker.postMessage({ inputPath, outputPath, sourcePrefix });
        this.worker.once('message', (err) => {
          err ? reject(err) : resolve();
        });
      });
    }

    const parsedOptions = parseRollupOptions(
      sourcePrefix + inputPath,
      this.rollupConfig,
    );
    const inputOptions = {
      ...parsedOptions.input,
      input: inputPath,
    };
    const outputOptions = {
      ...parsedOptions.output,
      file: outputPath,
    };

    const bundled = await rollup(inputOptions);
    await bundled.write(outputOptions);
  }

  /**
   * Destroy instance
   *
   * @returns { Promise<void> }
   */
  destroy() {
    if (this.worker) {
      // @ts-ignore
      return this.worker.terminate();
    }
    return Promise.resolve();
  }
}

var bundleWorker = BundleWorker;

// Create instance if run in Worker thread
if (!isMainThread && parentPort) {
  /** @type { string | undefined } */
  const rollupConfigPath = workerData;
  const bundleWorker = new BundleWorker(false, rollupConfigPath);

  parentPort.on('message', async (
    /** @type { BundleWorkerMessage } */ message,
  ) => {
    const { inputPath, outputPath, sourcePrefix } = message;

    try {
      await bundleWorker.bundle(inputPath, outputPath, sourcePrefix);
      parentPort.postMessage(false);
    } catch (err) {
      parentPort.postMessage(err);
    }
  });
}

/**
 * Merge user rollup-config with default
 *
 * @param { RollupOptions } defaultConfig
 * @param { RollupOptions } newConfig
 * @returns { RollupOptions }
 */
function mergeRollupConfig(defaultConfig, newConfig) {
  const {
    output: requiredOutput,
    plugins: defaultPlugins = [],
    ...defaultOptions
  } = defaultConfig;
  const { output, plugins = [], ...options } = newConfig;
  /** @type { { [name: string]: import('rollup').Plugin }}  */
  const newPluginsByName = plugins.reduce((newPluginsByName, plugin) => {
    // @ts-ignore
    newPluginsByName[plugin.name] = plugin;
    return newPluginsByName;
  }, {});
  let mergedPlugins = [];

  // Replace default plugin with new if it has the same name
  for (const plugin of defaultPlugins) {
    const { name } = plugin;
    mergedPlugins.push(
      name in newPluginsByName ? newPluginsByName[name] : plugin,
    );
  }

  return {
    ...defaultOptions,
    ...options,
    plugins: mergedPlugins,
    output: { ...output, ...requiredOutput },
  };
}

/**
 * Parse Rollup options
 *
 * @param { string } banner
 * @param { RollupOptions } options
 * @returns { { input: object, output: object } }
 */
function parseRollupOptions(banner, options) {
  if (!options) {
    return { input: {}, output: { banner } };
  }

  const { input, treeshake, output = {}, watch, ...inputOverride } = options;
  // @ts-ignore
  const { file, format, sourcemap, ...outputOverride } = output;

  if ('banner' in outputOverride) {
    outputOverride.banner = banner + outputOverride.banner;
  } else {
    // @ts-ignore
    outputOverride.banner = banner;
  }

  return { input: inputOverride, output: outputOverride };
}

module.exports = bundleWorker;

==> dvlp-9.2.0.tgz: package/bundle-worker.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var worker_threads = _interopDefault(require('worker_threads'));
var pluginCommonjs = _interopDefault(require('@rollup/plugin-commonjs'));
var pluginJson = _interopDefault(require('@rollup/plugin-json'));
var pluginReplace = _interopDefault(require('@rollup/plugin-replace'));
var pluginNodeResolve = _interopDefault(require('@rollup/plugin-node-resolve'));
var pirates = _interopDefault(require('pirates'));
var fs = _interopDefault(require('fs'));
var isModule = _interopDefault(require('is-module'));
var module$1 = _interopDefault(require('module'));
var path = _interopDefault(require('path'));
var sucrase = _interopDefault(require('sucrase'));
var rollup$1 = _interopDefault(require('rollup'));

let resolvePlugin = pluginNodeResolve;

if ('default' in resolvePlugin) {
  // @ts-ignore
  resolvePlugin = resolvePlugin.default;
}

const plugins = [
  // @ts-ignore
  pluginReplace({
    'process.env.NODE_ENV': `"${process.env.NODE_ENV}"` || '"development"',
  }),
  // @ts-ignore
  resolvePlugin({
    mainFields: ['browser', 'module', 'main'],
  }),
  // @ts-ignore
  pluginJson(),
  // @ts-ignore
  pluginCommonjs({
    sourceMap: false,
  }),
];

/**
 * Retrieve the default Rollup-config
 * @returns { import("rollup").RollupOptions }
 */
var getDefaultRollupConfig = function getDefaultRollupConfig() {
  return {
    // Only bundle local package files
    external: (id, parent, isResolved) => {
      // Skip if already handled by plugin
      if (isResolved || (parent && parent.includes('?commonjs-proxy'))) {
        return false;
      }
      return /^[^./\0]/.test(id);
    },
    plugins: plugins.slice(),
    treeshake: false,
    output: {
      format: 'es',
      sourcemap: false,
    },
  };
};

var defaultRollupConfig = {
	getDefaultRollupConfig: getDefaultRollupConfig
};

function createCommonjsModule(fn, basedir, module) {
	return module = {
	  path: basedir,
	  exports: {},
	  require: function (path, base) {
      return commonjsRequire(path, (base === undefined || base === null) ? module.path : base);
    }
	}, fn(module, module.exports), module.exports;
}

function commonjsRequire () {
	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
}

var module_1 = createCommonjsModule(function (module) {

const { addHook } = pirates;

// @ts-ignore

// Work around @rollup/plugin-commonjs dynamic require
// @ts-ignore
const loadModule = module$1._load;



const IMPORT_EXTS = ['.js', '.mjs'];
const IMPORT_EXTS_TRANSPILER = ['.js', '.jsx', '.mjs', '.ts', '.tsx'];
// Sync with config.js#extensionsByType
const JS_EXTENSIONS = ['.ts', '.tsx', '.mjs', '.jsx', '.js', '.json'];
const RE_TRANSPILER_HANDLES_SERVER = /\(\s?[a-zA-Z]+,\s?[a-zA-Z]+\s?\)/;

/** @type { () => void } */
let revertHook;

module.exports = {
  isModule: isModule$1,
  importModule,
};

/**
 * Determine if filePath or code is es module
 *
 * @param { string } filePathOrCode
 * @returns { boolean }
 */
function isModule$1(filePathOrCode) {
  if (
    !filePathOrCode.includes('\n') &&
    JS_EXTENSIONS.includes(path.extname(filePathOrCode))
  ) {
    filePathOrCode = fs.readFileSync(filePathOrCode, 'utf8');
  }
  return isModule(filePathOrCode);
}

/**
 * Import esm/cjs module, transpiling if necessary (via require hook)
 *
 * @param { string } modulePath
 * @param { Transpiler } [transpiler]
 * @returns { any }
 */
function importModule(modulePath, transpiler) {
  if (revertHook !== undefined) {
    revertHook();
  }

  revertHook = addHook(
    (code, filePath) => {
      // Determine if transpiler supports transpiling server modules by checking number of arguments (filePath, isServer) handled
      if (
        transpiler !== undefined &&
        RE_TRANSPILER_HANDLES_SERVER.test(transpiler.toString())
      ) {
        const transpiled = transpiler(filePath, true);

        if (transpiled !== undefined) {
          // Ignore async
          if (!(transpiled instanceof Promise)) {
            code = transpiled;
          }
        }
      }

      if (!isModule$1(code)) {
        return code;
      }

      return sucrase.transform(code, {
        transforms: ['imports'],
        filePath,
      }).code;
    },
    {
      exts: transpiler ? IMPORT_EXTS_TRANSPILER : IMPORT_EXTS,
      ignoreNodeModules: false,
    },
  );
  let mod = loadModule(modulePath, module, false);

  // Return default if only exported key
  if ('default' in mod && Object.keys(mod).length === 1) {
    mod = mod.default;
  }

  return mod;
}
});
var module_2 = module_1.isModule;
var module_3 = module_1.importModule;

/** @typedef { import("rollup").RollupOptions } RollupOptions */

const {
  isMainThread,
  parentPort,
  Worker,
  workerData,
} = worker_threads;
const {
  getDefaultRollupConfig: getDefaultRollupConfig$1,
} = defaultRollupConfig;
const { importModule } = module_1;
const { rollup } = rollup$1;

class BundleWorker {
  /**
   * Constructor
   *
   * @param { string } [rollupConfigPath]
   */
  constructor(rollupConfigPath) {
    const defaultConfig = getDefaultRollupConfig$1();

    this.rollupConfig = rollupConfigPath
      ? mergeRollupConfig(defaultConfig, importModule(rollupConfigPath))
      : defaultConfig;
    this.worker;

    if (isMainThread) {
      // Load this file in Worker thread, passing `rollupConfigPath` as data
      this.worker = new Worker(__filename, { workerData: rollupConfigPath });
    }
  }

  /**
   * Bundle file at "inputPath"
   *
   * @param { string } inputPath
   * @param { string } outputPath
   * @param { string } sourcePrefix
   */
  async bundle(inputPath, outputPath, sourcePrefix) {
    if (this.worker) {
      return new Promise((resolve, reject) => {
        this.worker.postMessage({ inputPath, outputPath, sourcePrefix });
        this.worker.once('message', (err) => {
          err ? reject(err) : resolve();
        });
      });
    }

    const parsedOptions = parseRollupOptions(
      sourcePrefix + inputPath,
      this.rollupConfig,
    );
    const inputOptions = {
      ...parsedOptions.input,
      input: inputPath,
    };
    const outputOptions = {
      ...parsedOptions.output,
      file: outputPath,
    };

    const bundled = await rollup(inputOptions);
    await bundled.write(outputOptions);
  }

  /**
   * Destroy instance
   *
   * @returns { Promise<void> }
   */
  destroy() {
    if (this.worker) {
      // @ts-ignore
      return this.worker.terminate();
    }
    return Promise.resolve();
  }
}

var bundleWorker = BundleWorker;

// Create instance if run in Worker thread
if (!isMainThread && parentPort) {
  /** @type { string | undefined } */
  const rollupConfigPath = workerData;
  const bundleWorker = new BundleWorker(rollupConfigPath);

  parentPort.on('message', async (
    /** @type { BundleWorkerMessage } */ message,
  ) => {
    const { inputPath, outputPath, sourcePrefix } = message;

    try {
      await bundleWorker.bundle(inputPath, outputPath, sourcePrefix);
      parentPort.postMessage(false);
    } catch (err) {
      parentPort.postMessage(err);
    }
  });
}

/**
 * Merge user rollup-config with default
 *
 * @param { RollupOptions } defaultConfig
 * @param { RollupOptions } newConfig
 * @returns { RollupOptions }
 */
function mergeRollupConfig(defaultConfig, newConfig) {
  const {
    output: requiredOutput,
    plugins: defaultPlugins = [],
    ...defaultOptions
  } = defaultConfig;
  const { output, plugins = [], ...options } = newConfig;
  /** @type { { [name: string]: import('rollup').Plugin }}  */
  const newPluginsByName = plugins.reduce((newPluginsByName, plugin) => {
    // @ts-ignore
    newPluginsByName[plugin.name] = plugin;
    return newPluginsByName;
  }, {});
  let mergedPlugins = [];

  // Replace default plugin with new if it has the same name
  for (const plugin of defaultPlugins) {
    const { name } = plugin;
    mergedPlugins.push(
      name in newPluginsByName ? newPluginsByName[name] : plugin,
    );
  }

  return {
    ...defaultOptions,
    ...options,
    plugins: mergedPlugins,
    output: { ...output, ...requiredOutput },
  };
}

/**
 * Parse Rollup options
 *
 * @param { string } banner
 * @param { RollupOptions } options
 * @returns { { input: object, output: object } }
 */
function parseRollupOptions(banner, options) {
  if (!options) {
    return { input: {}, output: { banner } };
  }

  const { input, treeshake, output = {}, watch, ...inputOverride } = options;
  // @ts-ignore
  const { file, format, sourcemap, ...outputOverride } = output;

  if ('banner' in outputOverride) {
    outputOverride.banner = banner + outputOverride.banner;
  } else {
    // @ts-ignore
    outputOverride.banner = banner;
  }

  return { input: inputOverride, output: outputOverride };
}

module.exports = bundleWorker;
